require 'uu/os/rest/paging_criteria'

module UU
  module OS
    module ArtifactSearch
      class ArtifactSearchQuery < UU::OS::REST::PagingCriteria

        # The <b>UES query</b> string. It has to conform to the ues query syntax (see documentation
        # for more info). Filtering and order of the result list can be specified there. When
        # null is set, no filtering is applied and entries are ordered by name of referenced
        # artifact (and code and type as the second and the third criteria).
        attr_accessor :query

        # Whether to search recursively (including subordinate organizational units), the root of the search
        # being the main entity of the command. Default is true.
        #
        # There's one special case - if this flag is set to false
        # and the query contains restriction on organizationalUnitUri attribute then the recursive applies
        # to that organizatinalUnitUri. That means that the searched entity must be located anywhere
        # in main entity (deep) and somewhere in specified organizationalUnitUri (shallow).
        attr_accessor :recursive

        # Whether to include system area (system territory) in the search. Default is false.
        attr_accessor :include_system_area
        
        # Whether to include preferred territory in the search. Default is false.
        attr_accessor :include_preferred_area

        def query
          attributes[:query]
        end

        def query=(val)
          attributes[:query] = val
        end

        def recursive
          attributes[:recursive]
        end

        def recursive=(val)
          attributes[:recursive] = val
        end

        def include_system_area
          attributes[:includeSystemArea]
        end

        def include_system_area=(val)
          attributes[:includeSystemArea] = val
        end
        
        def include_preferred_area
          attributes[:includePreferredArea]
        end
        
        def include_preferred_area=(val)
          attributes[:includePreferredArea] = val
        end
      end
    end
  end
end