require 'uu/os/rest/binary_value'
require 'uu/os/rest/dto'
require 'uu/os/env/version_strategy'

module UU
  module OS

      module Attachment

        class AttachmentCheckIn < UU::OS::REST::DTO

          # The new name of the attachment. When nil is set, the name is taken from the attachment file
          # name. The name must be unique in a given artifact, otherwise the checkIn command fails.
          attr_accessor :name

          # The new code of the attachment. When nil is set, the code is not modified. The code must be
          # unique in a given artifact, otherwise the checkIn command fails.
          attr_accessor :code

          # The new description of the attachment. When nil is set, the description is not modified.
          attr_accessor :description

          # Attachment data. When nil is set, the create command fails. Accepted values are
          # +String+, +IO+, +File+ or instance of +BinaryValue+. If use +BinaryValue+ attachment file name can be
          # set by attribute :name of it.
          attr_accessor :data

          # The version label of the new attachment version. When nil is set, it is left empty.
          attr_accessor :version_label

          # Specifies how to work with versions. If set to nil, the {https://api.plus4u.net/uuos/UU/OS/Env/VersionStrategy.html#OVERWRITE_VERSION-constant OVERWRITE_VERSION} strategy will be used 
          # (current version will be overwritten, published and the attachment will be unlocked).
          attr_accessor :version_strategy

          def name 
            attributes[:name]
          end

          def name=(val) 
            attributes[:name] = val
          end

          def code 
            attributes[:code]
          end

          def code=(val) 
            attributes[:code] = val
          end

          def description 
            attributes[:description]
          end

          def description=(val) 
            attributes[:description] = val
          end

          def data 
            attributes[:data]
          end

          def data=(val) 
            attributes[:data] = val
          end

          def version_label 
            attributes[:versionLabel]
          end

          def version_label=(val) 
            attributes[:versionLabel] = val
          end

          def version_strategy 
            attributes[:versionStrategy]
          end

          def version_strategy=(val) 
            attributes[:versionStrategy] = val
          end

          def to_hash 
            hash = super()
            if hash[:versionStrategy].nil?
              hash[:versionStrategy] = UU::OS::Env::VersionStrategy::OVERWRITE_VERSION
            end
            hash
          end

        end

      end

  end
end
