require 'uu/os/rest/binary_value'
require 'uu/os/rest/dto'

module UU
  module OS
      module Attachment

        class AttachmentCreate < UU::OS::REST::DTO

          # Code of the new attachment. When nil is set, the code is generated automatically
          # using the system sequence. The code must be unique in a given artifact, otherwise
          # the create command fails.
          attr_accessor :code

          # Name of the new attachment. When nil is set, the file name from data
          # is used (and a suffix is added to the name from data if needed to ensure
          # the name uniqueness.) The name must be unique in a given artifact, otherwise
          # the create command fails.
          attr_accessor :name

          # Description of the new attachment. When nil is set, the description is taken from
          # the template tDescription. When the template does not define a tDescription, it is
          # left empty.
          attr_accessor :description

          # Attachment data. When nil is set, the create command fails. Accepted values are
          # +String+, +IO+, +File+ or instance of +BinaryValue+. If use +BinaryValue+ attachment file name can be
          # set by attribute :name of it.
          attr_accessor :data

          # Version label of the created attachment version. When nil is set, versionLabel is
          # left empty.
          attr_accessor :version_label

          def code 
            attributes[:code]
          end

          def code=(val) 
            attributes[:code] = val
          end

          def name 
            attributes[:name]
          end

          def name=(val) 
            attributes[:name] = val
          end

          def description 
            attributes[:description]
          end

          def description=(val) 
            attributes[:description] = val
          end

          def data 
            attributes[:data]
          end

          def data=(val) 
            attributes[:data] = val
          end

          def version_label 
            attributes[:versionLabel]
          end

          def version_label=(val) 
            attributes[:versionLabel] = val
          end

        end

      end
    end

end
