require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module MetaUseCaseRealization
      # Meta Use Case Realization Copy DTO.
      # @deprecated Use {UU::OS::MetaVisualUseCase::MetaVisualUseCaseCopy} instead.
      class MetaUseCaseRealizationCopy < UU::OS::REST::DTO

        # UESURI of the meta model dictionary where to the meta use case realization will
        # be copied. If the rights does not permit to copy a meta use case realization from
        # the meta use case realization in this location, the copy command fails. The value
        # must not be nil.
        attr_accessor :location_uri

        # Name of the new meta use case realization. When nil is set, default name from meta
        # artifact is used if set, otherwise the create command fails.
        attr_accessor :name

        # Code of the new meta use case realization. When nil is set, the code is generated
        # automatically using the system sequence. The code must be unique in the given territory,
        # otherwise the create command fails.
        attr_accessor :code

        # Description of the new meta use case realization. When nil is set, default description
        # from meta artifact is used if set, otherwise no description is set on the new meta
        # use case realization.
        attr_accessor :description

        # UESURI of the competent role. When nil is set, the executive role from authorization
        # is used. If no role is authorized to create the role into specified container, the
        # create command fails. If the selected role doesn't have connected the role interface
        # with the selected meta artifact,the create command fails. If the selected role
        # doesn't belong to the same organizational unit as a new role or if it doesn't belong
        # to one of superior organizational units, the create command fails.
        attr_accessor :competent_role_uri

        # Security level. When nil is set, security level is taken from the source meta use
        # case realization security level. If the source meta use case realization security
        # level is higher than the user's security clearance, the copy command fails.
        attr_accessor :security_level

        # UESURI of the meta use case realization's icon. When nil is set, the meta use case
        # realization uses icon from meta artifact. <br> <br>Allowed format URI of icon:
        #
        # @example Allowed format of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{CODE_OF_ICON}
        #
        # @example An example of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{ART_077}
        attr_accessor :icon_uri

        # Specifies whether to copy content from the source meta use case realization to
        # the new copy. Default value is false.
        attr_accessor :copy_sheets

        # Specifies whether to copy life cycle from the source meta use case realization
        # to the new copy. Default value is false.
        attr_accessor :copy_lifecycle

        # Specifies whether to copy attachments from the source meta use case realization
        # to the new copy. Default value is false.
        attr_accessor :copy_attachments

        # Specifies whether to copy sheet templates from the source meta use case realization
        # to the new copy. Default value is false.
        attr_accessor :copy_sheet_templates

        # Specifies whether to copy options from the source meta use case realization to
        # the new copy. If copyOptions is set to true than options attribute must beset to
        # nil. Default value is false.
        attr_accessor :copy_options

        # Specifies default name of the created use case realization according to new meta
        # use case realization copy. When nil is set, the default name is taken from the source
        # meta use case realization.
        attr_accessor :default_name

        # Specifies default code of the created use case realization according to new meta
        # use case realization copy. When nil is set, the default code is taken from the source
        # meta use case realization.
        attr_accessor :default_code

        # Specifies default security level of the created use case realization according
        # to new meta use case realization copy. When nil is set, the default security level
        # is taken from the source meta use case realization.
        attr_accessor :default_security_level

        # Specifies default icon of the created use case realization according to new meta
        # use case realization copy. When nil is set, the default icon is taken from the source
        # meta use case realization.
        #
        # @example Allowed format of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{CODE_OF_ICON}
        #
        # @example An example of icon URI:
        #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{ART_077}
        attr_accessor :default_icon_uri

        # Options data for use case calling. Accepted format is JSON.
        attr_accessor :options
        def location_uri 
          attributes[:locationUri]
        end

        def location_uri=(val) 
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def name 
          attributes[:name]
        end

        def name=(val) 
          attributes[:name] = val
        end

        def code 
          attributes[:code]
        end

        def code=(val) 
          attributes[:code] = val
        end

        def description 
          attributes[:description]
        end

        def description=(val) 
          attributes[:description] = val
        end

        def competent_role_uri 
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val) 
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def security_level 
          attributes[:securityLevel]
        end

        def security_level=(val) 
          attributes[:securityLevel] = val
        end

        def icon_uri 
          attributes[:iconUri]
        end

        def icon_uri=(val) 
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def copy_sheets 
          attributes[:copySheets]
        end

        def copy_sheets=(val) 
          attributes[:copySheets] = val
        end

        def copy_lifecycle 
          attributes[:copyLifecycle]
        end

        def copy_lifecycle=(val) 
          attributes[:copyLifecycle] = val
        end

        def copy_attachments 
          attributes[:copyAttachments]
        end

        def copy_attachments=(val) 
          attributes[:copyAttachments] = val
        end

        def copy_sheet_templates 
          attributes[:copySheetTemplates]
        end

        def copy_sheet_templates=(val) 
          attributes[:copySheetTemplates] = val
        end

        def copy_options 
          attributes[:copyOptions]
        end

        def copy_options=(val) 
          attributes[:copyOptions] = val
        end

        def default_name 
          attributes[:defaultName]
        end

        def default_name=(val) 
          attributes[:defaultName] = val
        end

        def default_code 
          attributes[:defaultCode]
        end

        def default_code=(val) 
          attributes[:defaultCode] = val
        end

        def default_security_level 
          attributes[:defaultSecurityLevel]
        end

        def default_security_level=(val) 
          attributes[:defaultSecurityLevel] = val
        end

        def default_icon_uri 
          attributes[:defaultIconUri]
        end

        def default_icon_uri=(val) 
          if val
            attributes[:defaultIconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:defaultIconUri] = nil
          end
        end

        def options 
          attributes[:options]
        end

        def options=(val) 
          attributes[:options] = val
        end

      end
    end

  end
end
